@@ -7,9 +7,10 @@ import threading
 import concurrent.futures
 from shutil import get_terminal_size
 
+from plenty.table import Table
+from plenty import get_console
+
 from .common.utils import confirm, get_file_icon, adjudgment_type
-from .render.table import Table
-from .render import get_console
 
 
 Logger = logging.getLogger(__name__)
