@@ -4,17 +4,19 @@ import doctest
 from unittest.mock import patch
 from pprint import pprint
 
-import pigit.common.utils
 from pigit.common.utils import (
     traceback_info,
-    get_current_shell,
     confirm,
+    exec_cmd,
     async_run_cmd,
     exec_async_tasks,
 )
+from pigit.common.func import dynamic_default_attrs
 
 
 def test_doctest():
+    import pigit.common.utils
+
     doctest.testmod(pigit.common.utils, verbose=True)
 
 
@@ -28,10 +30,6 @@ def test_traceback_info():
     assert traceback_info() == ""
 
 
-def test_1():
-    print(get_current_shell())
-
-
 @pytest.mark.parametrize(
     ("input_value", "return_bool"),
     [
@@ -48,6 +46,23 @@ def test_confirm(mock_input, input_value: str, return_bool: bool):
     assert confirm("confirm:") == return_bool
 
 
+def test_exec_cmd():
+    # has reply
+    print(exec_cmd("pwd"))
+    print(exec_cmd("which", "python3"))
+
+    # output to shell
+    print(exec_cmd("pwd", reply=False))
+    print(exec_cmd("which", "python3", reply=False))
+
+    # don't decoding
+    print(exec_cmd("which", "python3", decoding=False))
+
+    # execute error
+    print(exec_cmd("xxxxxxxxx"))
+    print(exec_cmd("xxxxxxxxx", cwd="xxxxxxxxxxxx"))
+
+
 def test_async_cmd_func():
     print()
 
@@ -68,3 +83,18 @@ if __name__ == '__main__':
     pprint(tasks)
     result = exec_async_tasks(tasks)
     print(result)
+
+
+class TestFunc:
+    def test_dynamic_default_attrs(self):
+        da = {"c": 3, "d": 4}
+        f = dynamic_default_attrs(lambda a, b, c, d: (a, b, c, d), **da)
+
+        assert f(1, 2) == (1, 2, 3, 4)
+        assert f(1, 2, d=0) == (1, 2, 3, 0)
+        # assert f(1, 2, 0) == (1, 2, 0, 4)
+
+        def bp(a, b, c: int, d: int = 10):
+            return (a, b, c, d)
+
+        assert dynamic_default_attrs(bp, **da)(1, 2, 0) == (1, 2, 0, 4)
